import * as iam from '../../aws-iam';
import * as s3 from '../../aws-s3';
import * as s3_assets from '../../aws-s3-assets';
import { Construct } from '../../core';
/**
 * (experimental) Source information.
 *
 * @experimental
 */
export interface SourceConfig {
    /**
     * (experimental) The source bucket to deploy from.
     *
     * @experimental
     */
    readonly bucket: s3.IBucket;
    /**
     * (experimental) An S3 object key in the source bucket that points to a zip file.
     *
     * @experimental
     */
    readonly zipObjectKey: string;
    /**
     * (experimental) A set of markers to substitute in the source content.
     *
     * @default - no markers
     * @experimental
     */
    readonly markers?: Record<string, any>;
}
/**
 * (experimental) Bind context for ISources.
 *
 * @experimental
 */
export interface DeploymentSourceContext {
    /**
     * (experimental) The role for the handler.
     *
     * @experimental
     */
    readonly handlerRole: iam.IRole;
}
/**
 * (experimental) Represents a source for bucket deployments.
 *
 * @experimental
 */
export interface ISource {
    /**
     * (experimental) Binds the source to a bucket deployment.
     *
     * @param scope The construct tree context.
     * @experimental
     */
    bind(scope: Construct, context?: DeploymentSourceContext): SourceConfig;
}
/**
 * (experimental) Specifies bucket deployment source.
 *
 * Usage:
 *
 *      Source.bucket(bucket, key)
 *      Source.asset('/local/path/to/directory')
 *      Source.asset('/local/path/to/a/file.zip')
 *      Source.data('hello/world/file.txt', 'Hello, world!')
 *      Source.data('config.json', { baz: topic.topicArn })
 *
 * @experimental
 */
export declare class Source {
    /**
     * (experimental) Uses a .zip file stored in an S3 bucket as the source for the destination bucket contents.
     *
     * Make sure you trust the producer of the archive.
     *
     * @param bucket The S3 Bucket.
     * @param zipObjectKey The S3 object key of the zip file with contents.
     * @experimental
     */
    static bucket(bucket: s3.IBucket, zipObjectKey: string): ISource;
    /**
     * (experimental) Uses a local asset as the deployment source.
     *
     * If the local asset is a .zip archive, make sure you trust the
     * producer of the archive.
     *
     * @param path The path to a local .zip file or a directory.
     * @experimental
     */
    static asset(path: string, options?: s3_assets.AssetOptions): ISource;
    /**
     * (experimental) Deploys an object with the specified string contents into the bucket.
     *
     * The
     * content can include deploy-time values (such as `snsTopic.topicArn`) that
     * will get resolved only during deployment.
     *
     * To store a JSON object use `Source.jsonData()`.
     *
     * @param objectKey The destination S3 object key (relative to the root of the S3 deployment).
     * @param data The data to be stored in the object.
     * @experimental
     */
    static data(objectKey: string, data: string): ISource;
    /**
     * (experimental) Deploys an object with the specified JSON object into the bucket.
     *
     * The
     * object can include deploy-time values (such as `snsTopic.topicArn`) that
     * will get resolved only during deployment.
     *
     * @param objectKey The destination S3 object key (relative to the root of the S3 deployment).
     * @param obj A JSON object.
     * @experimental
     */
    static jsonData(objectKey: string, obj: any): ISource;
    private constructor();
}
